# Concurrently

**Version: 0.0.4** ([*previous stable*](https://github.com/kimmobrunfeldt/concurrently/tree/0.0.3))

Run multiple commands concurrently.
Like `npm run watch-js & npm run watch-less` but better.

![](docs/demo.gif)

## Install

The tool is written in Node.js, but you can use it to run **any** commands.

```bash
npm install -g concurrently
```

## Usage

Remember to surround separate commands with quotes, like this:
```bash
concurrent "command1 arg" "command2 arg"
```

Otherwise **concurrent** would try to run 4 separate commands:
`command1`, `arg`, `command2`, `arg`.

Help:

```
  Usage: concurrent [options] <command ...>

  Options:

    -h, --help             output usage information
    -V, --version          output the version number
    -k, --kill-others      kill other processes if one exits or dies
    --no-color             disable colors from logging
    -p, --prefix [prefix]  prefix used in logging for each process. Possible values: pid, none, command

  Examples:

   - Kill other processes if one exits or dies

       $ concurrent --kill-others "grunt watch" "http-server"

  For more details, visit https://github.com/kimmobrunfeldt/concurrently
```

## FAQ

* Process exited with code *null*?

    From [Node child_process documentation](http://nodejs.org/api/child_process.html#child_process_event_exit), `exit` event:
    ```
    This event is emitted after the child process ends. If the process terminated normally, code is the final exit code of the process, otherwise null. If the process terminated due to receipt of a signal, signal is the string name of the signal, otherwise null.
    ```

    So *null* means the process didn't terminate normally. This will make **concurrent**
    to return non-zero exit code too.


## Why

I like [task automation with npm](http://substack.net/task_automation_with_npm_run)
but the usual way to run multiple commands concurrently is
```npm run watch-js & npm run watch-css```. That's fine but it's hard to keep
on track of different outputs. Also if one process fails, others still keep running
and you won't even notice the difference.

Another option would be to just run all commands in separate terminals. I got
tired of opening terminals and made **concurrently**.

